==========
toonapilib
==========

A library to interact with eneco's "Toon" smart meter via their official api https://api.toon.eu


* Documentation: https://toonapilib.readthedocs.org/en/latest

Features
--------

* Reads values for gas, electric, temperature.
* Identifies connected hue lights and fibaro smartplugs
* Can read and set temperature and thermostat state
* Can turn lights or plugs on, off or toggle their state
* Can get consumption values from fibaro plugs
* More ...
